@@ -3,7 +3,7 @@ use std::path::PathBuf;
 use once_cell::sync::Lazy;
 
 /// Defines the crates's root directory.
-pub static ROOT: Lazy<PathBuf> = Lazy::new(|| env!("CARGO_MANIFEST_DIR").into());
+pub static CRATE_ROOT: Lazy<PathBuf> = Lazy::new(|| env!("CARGO_MANIFEST_DIR").into());
 
 /// Defines the user's home directory.
 //
@@ -12,9 +12,11 @@ pub static ROOT: Lazy<PathBuf> = Lazy::new(|| env!("CARGO_MANIFEST_DIR").into())
 // panic if that was the case.
 pub static HOME: Lazy<PathBuf> = Lazy::new(|| home::home_dir().unwrap());
 
-/// Defines the environment variable key used to determine weather testing is
-/// happening or not.
-///
-/// When testing, the official Apple Books database path is bypassed and
-/// redirected to the local testing database.
-pub const READSTOR_TESTING: &str = "READSTOR_TESTING";
+/// Defines the default template name.
+pub const DEFAULT_TEMPLATE_NAME: &str = "DEFAULT_TEMPLATE_NAME";
+
+/// Defines the default template.
+pub const DEFAULT_TEMPLATE: &str = include_str!(concat!(
+    env!("CARGO_MANIFEST_DIR"),
+    "/templates/default.txt"
+));
