@@ -3,13 +3,11 @@ use assert_cmd::Command;
 const COMMAND: &str = env!("CARGO_PKG_NAME");
 
 #[test]
-fn output_does_not_exit() -> Result<(), Box<dyn std::error::Error>> {
+fn output_does_not_exit() {
     let mut cmd = Command::cargo_bin(COMMAND).unwrap();
 
-    cmd.args(&["./path/does/not/exists"])
+    cmd.args(&["--output", "./path/does/not/exist"])
         .assert()
-        .code(1)
+        .code(2)
         .failure();
-
-    Ok(())
 }
